import { EventEmitter } from '../event';
import { IPrefersColorSchemeStatus } from './types';
/**
 * @typedef {String} PREFERS_COLOR_SCHEME
 * @alias PREFERS_COLOR_SCHEME
 * @memberof PrefersColorSchemeObserver
 * @property {String} LIGHT
 * @property {String} DARK
 */
/**
 * @export
 * @readonly
 * @enum {PREFERS_COLOR_SCHEME}
 */
export declare enum PREFERS_COLOR_SCHEME {
    LIGHT = "light",
    DARK = "dark"
}
/**
 * PrefersColorSchemeObserverEvent Types
 * @event PrefersColorSchemeObserver#PREFERS_COLOR_SCHEME_EVENTS
 * @memberof PrefersColorSchemeObserver
 * @property {String} CHANGE - 변경 시점
 * @property {String} GET_STATUS - 현재 상태값 체크
 */
/**
 * @export
 * @readonly
 * @enum {PREFERS_COLOR_SCHEME_EVENTS}
 */
export declare enum PREFERS_COLOR_SCHEME_EVENTS {
    CHANGE = "PREFERS_COLOR_SCHEME_OBSERVER-EVENTS-CHANGE",
    GET_STATUS = "PREFERS_COLOR_SCHEME_OBSERVER-EVENTS-GET_COLOR_SCHEME"
}
/**
 * prefers-color-scheme 상태 변화를 감지
 * @export
 * @class PrefersColorSchemeObserver
 * @alias observer/PrefersColorSchemeObserver
 * @extends EventEmitter
 * @throws {Error} browser 에서 지원하지 못하는 경우 - throw new Error('PrefersColorScheme 지원되지 않는 브라우저입니다.');
 */
export declare class PrefersColorSchemeObserver extends EventEmitter {
    private checkColorScheme;
    constructor();
    static isSupport(): boolean;
    attach(): PrefersColorSchemeObserver;
    detach(): PrefersColorSchemeObserver;
    getStatus(): IPrefersColorSchemeStatus;
    /**
     * 변화 감지 이벤트 리스너
     * @private
     * @memberof PrefersColorSchemeObserver
     * @fires PrefersColorSchemeObserver#PREFERS_COLOR_SCHEME_EVENTS
     */
    private onPrefersColorSchemeChangeListener;
    /**
     * destroy
     * @returns {PrefersColorSchemeObserver}
     * @memberof PrefersColorSchemeObserver
     */
    destroy(): PrefersColorSchemeObserver;
}
